@@ -4,12 +4,15 @@ use strict;
 use warnings;
 
 use base 'Class::Accessor';
-use POSIX qw(strftime setlocale LC_TIME LC_CTYPE);
+
+use DateTime;
+
+use POSIX qw(setlocale LC_TIME LC_CTYPE);
 
 __PACKAGE__->mk_accessors(qw|groups xml_options outline group xml_head xml_outlines xml|);
 
 # Version set by dist.ini; do not change here.
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 sub new {
     my $class = shift;
@@ -54,16 +57,31 @@ sub new {
     # Force locale to 'C' rather than local, then reset after setting times.
     # Fixes RT51000.  Thanks to KAPPA for the patch.
     my $old_loc = POSIX::setlocale(LC_TIME, "C");
+    my $ts_ar = [ localtime() ];
     $self->head(
         title => '',
-        dateCreated  => strftime( "%a, %e %b %Y %H:%M:%S %z", localtime ),
-        dateModified => strftime( "%a, %e %b %Y %H:%M:%S %z", localtime ),
+        $self->_date( dateCreated  => $ts_ar ),
+        $self->_date( dateModified => $ts_ar ),
     );
     POSIX::setlocale(LC_TIME,$old_loc);
 
     return $self;
 }
 
+sub _date {
+  my $self  = shift;
+  my $type  = shift; # dateCreated or dateModified.
+  my $ts_ar = shift; # e.g [ localtime() ]
+
+  my %arg;
+  @arg{qw(second minute hour day month year)} = (
+      @{$ts_ar}[0..3],
+      $ts_ar->[4]+1,
+      $ts_ar->[5]+1900 );
+  my $dt = DateTime->new( %arg );
+  return ( $type => $dt->strftime('%a, %e %b %Y %H:%M:%S %z') );
+}
+
 sub id {
     my $self = shift;
     
@@ -161,8 +179,8 @@ sub save {
 
 # ABSTRACT:  create OPML using XML::Simple
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -171,7 +189,7 @@ XML::OPML::SimpleGen - create OPML using XML::Simple
 
 =head1 VERSION
 
-version 0.05
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -288,9 +306,16 @@ L<https://github.com/stephenca/XML-OPML-SimpleGen>
 
 =head1 CONTRIBUTORS
 
-KAPPA C<< <kappa@cpan.org> >> contributed a patch to close RT51000
+=over 4
+
+=item KAPPA C<< <kappa@cpan.org> >> contributed a patch to close RT51000
 L<https://rt.cpan.org/Public/Bug/Display.html?id=51000>
 
+=item gregoa@debian.org contributed a patch to close RT77725
+L<https://rt.cpan.org/Public/Bug/Display.html?id=77725>
+
+=back
+
 =head1 REPO
 
   The git repository for this module is at
@@ -314,10 +339,9 @@ Marcus Theisen <marcus@thiesen.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Marcus Thiesen.
+This software is copyright (c) 2013 by Marcus Thiesen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
